[xiph-cvs] cvs commit: shout-python INSTALL README setup.py shout.c

Brendan brendan at xiph.org
Sun Jul 13 10:29:54 PDT 2003



brendan     03/07/13 13:29:54

  Modified:    .        INSTALL README setup.py shout.c
  Log:
  shout-python 0.1

Revision  Changes    Path
1.2       +3 -4      shout-python/INSTALL

Index: INSTALL
===================================================================
RCS file: /usr/local/cvsroot/shout-python/INSTALL,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -p -u -r1.1 -r1.2
--- INSTALL	3 Jul 2003 17:30:44 -0000	1.1
+++ INSTALL	13 Jul 2003 17:29:53 -0000	1.2
@@ -1,10 +1,9 @@
 Prerequisites
 -------------
 
-You need to have a recent version of libshout 2 installed. If you have
-pkg-config installed, make sure it can find shout (you may need to
-adjust PKG_CONFIG_PATH to contain
-$shout_prefix/lib/pkgcofig). Otherwise, shout-config must appear in
+You need to have libshout 2 installed. If you have pkg-config installed,
+make sure it can find shout (you may need to adjust PKG_CONFIG_PATH to
+contain $shout_prefix/lib/pkgcofig). Otherwise, shout-config must appear in
 your path.
 
 Installation

<p><p>1.2       +3 -3      shout-python/README

Index: README
===================================================================
RCS file: /usr/local/cvsroot/shout-python/README,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -p -u -r1.1 -r1.2
--- README	3 Jul 2003 17:30:44 -0000	1.1
+++ README	13 Jul 2003 17:29:53 -0000	1.2
@@ -1,7 +1,7 @@
-This is pyshout2, a set of bindings for libshout 2.
+This is shout-python, a set of bindings for libshout 2.
 
-Pyshout2 allows you to act as a source for icecast 1 and 2, and
+shout-python allows you to act as a source for icecast 1 and 2, and
 shoutcast. This module includes inline documentation, or see
 the included example.py for a demonstration of its usage.
 
-pyshout2 is licensed under the GNU LGPL. See COPYING for details.
\ No newline at end of file
+shout-python is licensed under the GNU LGPL. See COPYING for details.
\ No newline at end of file

<p><p>1.3       +4 -4      shout-python/setup.py

Index: shout.c
===================================================================
RCS file: /usr/local/cvsroot/shout-python/shout.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -p -u -r1.2 -r1.3
--- shout.c	9 Jul 2003 21:56:43 -0000	1.2
+++ shout.c	13 Jul 2003 17:29:53 -0000	1.3
@@ -1,10 +1,22 @@
 /* shout.c: python bindings to libshout
  * Copyright (c) 2003 Brendan Cully <brendan at xiph.org>
  *
- * This code is licensed under the GNU LGPL. See COPYING in the source
- * distribution for details.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Library General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- * $Id: shout.c,v 1.2 2003/07/09 21:56:43 brendan Exp $
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public
+ *  License along with this library; if not, write to the 
+ *  Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
+ *  Boston, MA  02111-1307  USA.
+ *
+ * $Id: shout.c,v 1.3 2003/07/13 17:29:53 brendan Exp $
  */
 
 #include <Python.h>

<p><p>--- >8 ----
List archives:  http://www.xiph.org/archives/
Ogg project homepage: http://www.xiph.org/ogg/
To unsubscribe from this list, send a message to 'cvs-request at xiph.org'
containing only the word 'unsubscribe' in the body.  No subject is needed.
Unsubscribe messages sent to the list will be ignored/filtered.



More information about the commits mailing list
Index: setup.py
===================================================================
RCS file: /usr/local/cvsroot/shout-python/setup.py,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -p -u -r1.2 -r1.3
--- setup.py	9 Jul 2003 21:57:28 -0000	1.2
+++ setup.py	13 Jul 2003 17:29:53 -0000	1.3
@@ -1,11 +1,11 @@
 # distutils build script
 # To install pyshout2, run 'python setup.py install'
 
 from distutils.core import setup, Extension
 import os
 import sys
 
-ver = '0.0.3'
+ver = '0.1'
 
 # write default shout.pc path into environment if PKG_CONFIG_PATH is unset
 if not os.environ.has_key('PKG_CONFIG_PATH'):
@@ -52,10 +52,10 @@ shout = Extension('shout', sources = ['s
                   libraries = libsonly)
 
 # data_files = []
-setup (name = 'pyshout2',
+setup (name = 'shout-python',
        version = ver,
        description = 'Bindings for libshout 2',
-       url = 'http://xiph.org/~brendan/pyshout2/',
+       url = 'http://xiph.org/~brendan/shout-python/',
        author = 'Brendan Cully',
        author_email = 'brendan at xiph.org',
        ext_modules = [shout])
@@ -1,11 +1,11 @@
 # distutils build script
-# To install pyshout2, run 'python setup.py install'
+# To install shout-python, run 'python setup.py install'
 
 from distutils.core import setup, Extension

<p><p>1.3       +15 -3     shout-python/shout.c
